@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@
 
 using namespace NoteShared;
 
-NoteUtils::NoteUtils()
-{
-}
+NoteUtils::NoteUtils() = default;
 
 bool NoteUtils::sendToMail(QWidget *parent, const QString &title, const QString &message)
 {
@@ -80,9 +78,9 @@ void NoteUtils::sendToNetwork(QWidget *parent, const QString &title, const QStri
 
 QString NoteUtils::createToolTip(const Akonadi::Item &item)
 {
-    const KMime::Message::Ptr noteMessage = item.payload<KMime::Message::Ptr>();
+    const auto noteMessage = item.payload<KMime::Message::Ptr>();
     if (!noteMessage) {
-        return QString();
+        return {};
     }
     const QString description = QString::fromUtf8(noteMessage->mainBodyPart()->decodedContent());
     const KMime::Headers::Subject *const subject = noteMessage->subject(false);
@@ -92,7 +90,7 @@ QString NoteUtils::createToolTip(const Akonadi::Item &item)
 
     QString tip;
     if (item.hasAttribute<NoteDisplayAttribute>()) {
-        const auto *attr = item.attribute<NoteDisplayAttribute>();
+        const auto attr = item.attribute<NoteDisplayAttribute>();
         if (attr) {
             const QString bckColorName = attr->backgroundColor().name();
             const QString txtColorName = attr->foregroundColor().name();
